@@ -193,6 +193,25 @@ class TestFTSInputValidation(unittest.TestCase):
 
                 # THEN no error should be raised
 
+    def test_correct_order2(self) -> None:
+        """ Test providing GreenYellowInterval in the correct periodic order """
+        # GIVEN
+        input_dict = TestFTSInputValidation.get_default_inputs()
+        for first_interval in range(3):
+            with self.subTest(f"first interval={first_interval}"):
+                input_dict["greenyellow_intervals"]["id3"] = \
+                    [GreenYellowInterval(start_greenyellow=70, end_greenyellow=20),
+                     GreenYellowInterval(start_greenyellow=30, end_greenyellow=40),
+                     GreenYellowInterval(start_greenyellow=50, end_greenyellow=60)]
+                input_dict["greenyellow_intervals"]["id3"] = \
+                    input_dict["greenyellow_intervals"]["id3"][first_interval:] + \
+                    input_dict["greenyellow_intervals"]["id3"][:first_interval]
+
+                # WHEN initializing the fts
+                FixedTimeSchedule(**input_dict)
+
+                # THEN no error should be raised
+
     def test_wrong_order(self) -> None:
         """ Test providing GreenYellowInterval in the wrong periodic order """
         # GIVEN
@@ -213,6 +232,26 @@ class TestFTSInputValidation(unittest.TestCase):
 
                     # THEN an error should be raised
 
+    def test_wrong_order2(self) -> None:
+        """ Test providing GreenYellowInterval in the wrong periodic order """
+        # GIVEN
+        input_dict = TestFTSInputValidation.get_default_inputs()
+        for first_interval in range(3):
+            with self.subTest(f"first interval={first_interval}"):
+                input_dict["greenyellow_intervals"]["id3"] = \
+                    [GreenYellowInterval(start_greenyellow=70, end_greenyellow=20),
+                     GreenYellowInterval(start_greenyellow=50, end_greenyellow=60),
+                     GreenYellowInterval(start_greenyellow=30, end_greenyellow=40)]
+                input_dict["greenyellow_intervals"]["id3"] = \
+                    input_dict["greenyellow_intervals"]["id3"][first_interval:] + \
+                    input_dict["greenyellow_intervals"]["id3"][:first_interval]
+
+                with self.assertRaises(ValueError):
+                    # WHEN initializing the fts
+                    FixedTimeSchedule(**input_dict)
+
+                    # THEN an error should be raised
+
     def test_not_overlapping(self) -> None:
         """ Test providing non-overlapping GreenYellowInterval """
         # GIVEN
@@ -231,6 +270,24 @@ class TestFTSInputValidation(unittest.TestCase):
 
                 # THEN no error should be raised
 
+    def test_not_overlapping2(self) -> None:
+        """ Test providing non-overlapping GreenYellowInterval """
+        # GIVEN
+        input_dict = TestFTSInputValidation.get_default_inputs()
+        for first_interval in range(2):
+            with self.subTest(f"first interval={first_interval}"):
+                input_dict["greenyellow_intervals"]["id3"] = \
+                    [GreenYellowInterval(start_greenyellow=70, end_greenyellow=20),
+                     GreenYellowInterval(start_greenyellow=20, end_greenyellow=40)]  # at the verge of overlap
+                input_dict["greenyellow_intervals"]["id3"] = \
+                    input_dict["greenyellow_intervals"]["id3"][first_interval:] + \
+                    input_dict["greenyellow_intervals"]["id3"][:first_interval]
+
+                # WHEN initializing the fts
+                FixedTimeSchedule(**input_dict)
+
+                # THEN no error should be raised
+
     def test_overlapping(self) -> None:
         """ Test providing overlapping GreenYellowInterval """
         # GIVEN
@@ -250,6 +307,25 @@ class TestFTSInputValidation(unittest.TestCase):
 
                     # THEN an error should be raised
 
+    def test_overlapping2(self) -> None:
+        """ Test providing overlapping GreenYellowInterval """
+        # GIVEN
+        input_dict = TestFTSInputValidation.get_default_inputs()
+        for first_interval in range(2):
+            with self.subTest(f"first interval={first_interval}"):
+                input_dict["greenyellow_intervals"]["id3"] = \
+                    [GreenYellowInterval(start_greenyellow=70, end_greenyellow=20),
+                     GreenYellowInterval(start_greenyellow=15, end_greenyellow=40)]
+                input_dict["greenyellow_intervals"]["id3"] = \
+                    input_dict["greenyellow_intervals"]["id3"][first_interval:] + \
+                    input_dict["greenyellow_intervals"]["id3"][:first_interval]
+
+                with self.assertRaises(ValueError):
+                    # WHEN initializing the fts
+                    FixedTimeSchedule(**input_dict)
+
+                    # THEN an error should be raised
+
     def test_comparing_success(self):
         """ Test comparing two equal fixed-time schedules """
         # GIVEN
@@ -332,6 +408,23 @@ class TestFTSMethods(unittest.TestCase):
         self.assertEqual(fts.get_greenyellow_intervals(signalgroup=sg1), input_dict["greenyellow_intervals"]["sg1"])
         self.assertEqual(fts.get_greenyellow_intervals(signalgroup=sg2), input_dict["greenyellow_intervals"]["sg2"])
 
+    def test_retrieving_greenyellow_intervals_by_id(self):
+        # GIVEN
+        input_dict = TestFTSMethods.get_default_fts_inputs()
+        sg1 = SignalGroup(id="sg1", traffic_lights=[TrafficLight(capacity=800, lost_time=1)],
+                          min_greenyellow=10, max_greenyellow=80, min_red=10, max_red=80)
+        sg2 = SignalGroup(id="sg2", traffic_lights=[TrafficLight(capacity=800, lost_time=1)],
+                          min_greenyellow=10, max_greenyellow=80, min_red=10, max_red=80)
+
+        # WHEN
+        fts = FixedTimeSchedule(**input_dict)
+
+        # using id should give the same result
+        self.assertEqual(fts.get_greenyellow_intervals(signalgroup=sg1),
+                         fts.get_greenyellow_intervals(signalgroup=sg1.id))
+        self.assertEqual(fts.get_greenyellow_intervals(signalgroup=sg2),
+                         fts.get_greenyellow_intervals(signalgroup=sg2.id))
+
     def test_retrieving_for_unkown_signalgroup(self):
         """ test retrieving greenyellow intervals of an unkown signal group """
         # GIVEN
@@ -348,6 +441,13 @@ class TestFTSMethods(unittest.TestCase):
 
             # THEN an error should be raised
 
+        # same but using id
+        with self.assertRaises(ValueError):
+            # WHEN trying to access greenyellow intervals of an unkown signal group
+            fts.get_greenyellow_intervals(sg3.id)
+
+            # THEN an error should be raised
+
     def test_retrieving_single_greenyellow_interval(self):
         """ test retrieving a single greenyellow interval of a signal group """
         # GIVEN
@@ -365,10 +465,28 @@ class TestFTSMethods(unittest.TestCase):
                          input_dict["greenyellow_intervals"]["sg1"][0])
         self.assertEqual(fts.get_greenyellow_interval(signalgroup=sg1, k=1),
                          input_dict["greenyellow_intervals"]["sg1"][1])
-
         self.assertEqual(fts.get_greenyellow_interval(signalgroup=sg2, k=0),
                          input_dict["greenyellow_intervals"]["sg2"][0])
 
+    def test_retrieving_single_interval_with_id(self):
+        # GIVEN
+        input_dict = TestFTSMethods.get_default_fts_inputs()
+        sg1 = SignalGroup(id="sg1", traffic_lights=[TrafficLight(capacity=800, lost_time=1)],
+                          min_greenyellow=10, max_greenyellow=80, min_red=10, max_red=80)
+        sg2 = SignalGroup(id="sg2", traffic_lights=[TrafficLight(capacity=800, lost_time=1)],
+                          min_greenyellow=10, max_greenyellow=80, min_red=10, max_red=80)
+
+        # WHEN
+        fts = FixedTimeSchedule(**input_dict)
+
+        # THEN using id should give the same information
+        self.assertEqual(fts.get_greenyellow_interval(signalgroup=sg1, k=0),
+                         fts.get_greenyellow_interval(signalgroup=sg1.id, k=0))
+        self.assertEqual(fts.get_greenyellow_interval(signalgroup=sg1, k=1),
+                         fts.get_greenyellow_interval(signalgroup=sg1.id, k=1))
+        self.assertEqual(fts.get_greenyellow_interval(signalgroup=sg2, k=0),
+                         fts.get_greenyellow_interval(signalgroup=sg2.id, k=0))
+
     def test_retrieving_single_interval_for_unkown_signalgroup(self):
         """ test retrieving greenyellow intervals of an unkown signal group """
         # GIVEN
